geowatch.tasks.fusion.methods.unet\_baseline module
===================================================

.. automodule:: geowatch.tasks.fusion.methods.unet_baseline
   :members:
   :undoc-members:
   :show-inheritance:
